==> eam-wshub-proxyclient-12.1.0-21-sources.jar: net/datastream/schemas/mp_fields/CUESTIMATEWORKPOINTID_Type.java <==

package net.datastream.schemas.mp_fields;

import jakarta.xml.bind.annotation.XmlAccessType;
import jakarta.xml.bind.annotation.XmlAccessorType;
import jakarta.xml.bind.annotation.XmlElement;
import jakarta.xml.bind.annotation.XmlType;


/**
 * <p>Java class for CUESTIMATEWORKPOINTID_Type complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>{@code
 * <complexType name="CUESTIMATEWORKPOINTID_Type">
 *   <complexContent>
 *     <restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       <sequence>
 *         <element ref="{http://schemas.datastream.net/MP_fields}CUESTIMATEID"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}WORKPOINTID"/>
 *       </sequence>
 *     </restriction>
 *   </complexContent>
 * </complexType>
 * }</pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "CUESTIMATEWORKPOINTID_Type", propOrder = {
    "cuestimateid",
    "workpointid"
})
public class CUESTIMATEWORKPOINTID_Type {

    @XmlElement(name = "CUESTIMATEID", required = true)
    protected STANDARDENTITYID_Type cuestimateid;
    @XmlElement(name = "WORKPOINTID", required = true)
    protected STANDARDENTITYID_Type workpointid;

    /**
     * Gets the value of the cuestimateid property.
     * 
     * @return
     *     possible object is
     *     {@link STANDARDENTITYID_Type }
     *     
     */
    public STANDARDENTITYID_Type getCUESTIMATEID() {
        return cuestimateid;
    }

    /**
     * Sets the value of the cuestimateid property.
     * 
     * @param value
     *     allowed object is
     *     {@link STANDARDENTITYID_Type }
     *     
     */
    public void setCUESTIMATEID(STANDARDENTITYID_Type value) {
        this.cuestimateid = value;
    }

    /**
     * Gets the value of the workpointid property.
     * 
     * @return
     *     possible object is
     *     {@link STANDARDENTITYID_Type }
     *     
     */
    public STANDARDENTITYID_Type getWORKPOINTID() {
        return workpointid;
    }

    /**
     * Sets the value of the workpointid property.
     * 
     * @param value
     *     allowed object is
     *     {@link STANDARDENTITYID_Type }
     *     
     */
    public void setWORKPOINTID(STANDARDENTITYID_Type value) {
        this.workpointid = value;
    }

}

==> eam-wshub-proxyclient-12.1-4-sources.jar: net/datastream/schemas/mp_fields/CUESTIMATEWORKPOINTID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for CUESTIMATEWORKPOINTID_Type complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="CUESTIMATEWORKPOINTID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}CUESTIMATEID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}WORKPOINTID"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "CUESTIMATEWORKPOINTID_Type", propOrder = {
    "cuestimateid",
    "workpointid"
})
public class CUESTIMATEWORKPOINTID_Type {

    @XmlElement(name = "CUESTIMATEID", required = true)
    protected STANDARDENTITYID_Type cuestimateid;
    @XmlElement(name = "WORKPOINTID", required = true)
    protected STANDARDENTITYID_Type workpointid;

    /**
     * Gets the value of the cuestimateid property.
     * 
     * @return
     *     possible object is
     *     {@link STANDARDENTITYID_Type }
     *     
     */
    public STANDARDENTITYID_Type getCUESTIMATEID() {
        return cuestimateid;
    }

    /**
     * Sets the value of the cuestimateid property.
     * 
     * @param value
     *     allowed object is
     *     {@link STANDARDENTITYID_Type }
     *     
     */
    public void setCUESTIMATEID(STANDARDENTITYID_Type value) {
        this.cuestimateid = value;
    }

    /**
     * Gets the value of the workpointid property.
     * 
     * @return
     *     possible object is
     *     {@link STANDARDENTITYID_Type }
     *     
     */
    public STANDARDENTITYID_Type getWORKPOINTID() {
        return workpointid;
    }

    /**
     * Sets the value of the workpointid property.
     * 
     * @param value
     *     allowed object is
     *     {@link STANDARDENTITYID_Type }
     *     
     */
    public void setWORKPOINTID(STANDARDENTITYID_Type value) {
        this.workpointid = value;
    }

}
